import CloudFlare
import dns.resolver

def get_current_ips(domain):
    answers = dns.resolver.resolve(domain, 'A')
    ips = [answer.address for answer in answers]
    return ips

def update_dns_records(domain, new_ips):
    cf = CloudFlare.CloudFlare(email='email', token='global api')
    
    zones = cf.zones.get(params={'name': 'cfip.cc'})
    zone_id = zones[0]['id']
    
    # 获取yx.cfip.cc域名的DNS记录
    dns_records = cf.zones.dns_records.get(zone_id, params={'name': domain})
    
    # 删除现有的A记录
    for record in dns_records:
        if record['type'] == 'A' and record['name'] == domain:
            record_id = record['id']
            cf.zones.dns_records.delete(zone_id, record_id)
    
    # 更新特定域名下的A记录
    for ip in new_ips:
        dns_record = {'name': domain, 'type': 'A', 'content': ip, 'ttl': 1, 'proxied': False}
        cf.zones.dns_records.post(zone_id, data=dns_record)
        print(f"DNS记录已更新：{domain} -> {ip}")

if __name__ == "__main__":
    stock_domain = 'stock.hostmonit.com'
    cff_domain = 'yx.cfip.cc'
    new_ips = get_current_ips(stock_domain)
    update_dns_records(cff_domain, new_ips)